@@ -278,4 +278,4 @@ class GcodeCursor:
         Closes file.
         Writing functions will now throw errors.
         '''
-        self._file.close()
+        self.__file.close()
